@@ -70,23 +70,37 @@ class Screen(BaseScreen, RealTerminal):
         self.prev_input_resize = 0
         self.set_input_timeouts()
         self.last_bstate = 0
+        self._mouse_tracking_enabled = False
 
         self.register_palette_entry(None, 'default','default')
 
-    def set_mouse_tracking(self):
+    def set_mouse_tracking(self, enable=True):
         """
         Enable mouse tracking.
 
         After calling this function get_input will include mouse
         click events along with keystrokes.
         """
-        curses.mousemask(0
-            | curses.BUTTON1_PRESSED | curses.BUTTON1_RELEASED
-            | curses.BUTTON2_PRESSED | curses.BUTTON2_RELEASED
-            | curses.BUTTON3_PRESSED | curses.BUTTON3_RELEASED
-            | curses.BUTTON4_PRESSED | curses.BUTTON4_RELEASED
-            | curses.BUTTON_SHIFT | curses.BUTTON_ALT
-            | curses.BUTTON_CTRL)
+        enable = bool(enable)
+        if enable == self._mouse_tracking_enabled:
+            return
+
+        if enable:
+            curses.mousemask(0
+                | curses.BUTTON1_PRESSED | curses.BUTTON1_RELEASED
+                | curses.BUTTON2_PRESSED | curses.BUTTON2_RELEASED
+                | curses.BUTTON3_PRESSED | curses.BUTTON3_RELEASED
+                | curses.BUTTON4_PRESSED | curses.BUTTON4_RELEASED
+                | curses.BUTTON1_DOUBLE_CLICKED | curses.BUTTON1_TRIPLE_CLICKED
+                | curses.BUTTON2_DOUBLE_CLICKED | curses.BUTTON2_TRIPLE_CLICKED
+                | curses.BUTTON3_DOUBLE_CLICKED | curses.BUTTON3_TRIPLE_CLICKED
+                | curses.BUTTON4_DOUBLE_CLICKED | curses.BUTTON4_TRIPLE_CLICKED
+                | curses.BUTTON_SHIFT | curses.BUTTON_ALT
+                | curses.BUTTON_CTRL)
+        else:
+            raise NotImplementedError()
+
+        self._mouse_tracking_enabled = enable
 
     def start(self):
         """
@@ -397,6 +411,24 @@ class Screen(BaseScreen, RealTerminal):
             append_button( 64 + escape.MOUSE_RELEASE_FLAG )
             next &= ~ 8
         
+        if bstate & curses.BUTTON1_DOUBLE_CLICKED:
+            append_button( 0 + escape.MOUSE_MULTIPLE_CLICK_FLAG )
+        if bstate & curses.BUTTON2_DOUBLE_CLICKED:
+            append_button( 1 + escape.MOUSE_MULTIPLE_CLICK_FLAG )
+        if bstate & curses.BUTTON3_DOUBLE_CLICKED:
+            append_button( 2 + escape.MOUSE_MULTIPLE_CLICK_FLAG )
+        if bstate & curses.BUTTON4_DOUBLE_CLICKED:
+            append_button( 64 + escape.MOUSE_MULTIPLE_CLICK_FLAG )
+
+        if bstate & curses.BUTTON1_TRIPLE_CLICKED:
+            append_button( 0 + escape.MOUSE_MULTIPLE_CLICK_FLAG*2 )
+        if bstate & curses.BUTTON2_TRIPLE_CLICKED:
+            append_button( 1 + escape.MOUSE_MULTIPLE_CLICK_FLAG*2 )
+        if bstate & curses.BUTTON3_TRIPLE_CLICKED:
+            append_button( 2 + escape.MOUSE_MULTIPLE_CLICK_FLAG*2 )
+        if bstate & curses.BUTTON4_TRIPLE_CLICKED:
+            append_button( 64 + escape.MOUSE_MULTIPLE_CLICK_FLAG*2 )
+
         self.last_bstate = next
         return l
             
