@@ -245,8 +245,8 @@ class Screen(BaseScreen, RealTerminal):
         self._term_output_file.write(
             self._attrspec_to_escape(AttrSpec('',''))
             + escape.SI
-            + escape.SHOW_CURSOR
-            + move_cursor + "\n" + escape.SHOW_CURSOR )
+            + move_cursor
+            + escape.SHOW_CURSOR)
         self._input_iter = self._fake_input_iter()
 
         if self._old_signal_keys:
@@ -350,7 +350,7 @@ class Screen(BaseScreen, RealTerminal):
         Return a list of integer file descriptors that should be
         polled in external event loops to check for user input.
 
-        Use this method if you are implementing yout own event loop.
+        Use this method if you are implementing your own event loop.
         """
         if not self._started:
             return []
@@ -379,7 +379,7 @@ class Screen(BaseScreen, RealTerminal):
     def _run_input_iter(self):
         def empty_resize_pipe():
             # clean out the pipe used to signal external event loops
-            # that a resize has occured
+            # that a resize has occurred
             try:
                 while True: os.read(self._resize_pipe_rd, 1)
             except OSError:
@@ -931,7 +931,7 @@ class Screen(BaseScreen, RealTerminal):
         """
         entries - list of (index, red, green, blue) tuples.
 
-        Attempt to set part of the terminal pallette (this does not work
+        Attempt to set part of the terminal palette (this does not work
         on all terminals.)  The changes are sent as a single escape
         sequence so they should all take effect at the same time.
         
